@@ -2,6 +2,10 @@ use MooseX::Declare;
 
 class TSQL::AST::SQLIfStatement extends TSQL::AST::SQLStatement {
 
+use TSQL::AST::SQLStatement;
+use TSQL::AST::SQLConditionalExpression;
+use TSQL::AST::SQLStatementBlock;
+
 has 'condition' => (
       is  => 'rw',
       isa => 'TSQL::AST::SQLConditionalExpression',
@@ -10,13 +14,13 @@ has 'condition' => (
 
 has 'ifBranch' => (
       is  => 'rw',
-      isa => 'TSQL::AST::SQLStatement',
+      isa => 'TSQL::AST::SQLStatement | TSQL::AST::SQLStatementBlock',
   );
 
 
 has 'elseBranch' => (
       is  => 'rw',
-      isa => 'TSQL::AST::SQLStatement',
+      isa => 'TSQL::AST::SQLStatement | TSQL::AST::SQLStatementBlock',
   );
 
 
